Rendering with Proxies take about 5-10 times longer than before proxy export

Hey Guys,

in our pipeline we rely heavily upon Vray Proxies…for the most flexibility we export one proxy per Mesh/Shape. This results in a lot of proxies…sometimes thousands…

In our latest setup we noticed that there was a dramatic increase in rendertimes after we switched to a proxy-only scene. What rendered in 2 minutes before now takes far more than 10 minutes

Is there anything i should be aware of when using proxies or are there settings to force vray to load them as static objects?

Any help would be greatly appreciated!!!

cheers
Oliver

What is your dynamic memory limit set to?

Best regards,
Vlado

It is currently at 12000…rendering with vray standalone uses just about 3000MB…so i think this is not the issue… i have also tried using just 4 combined proxy objects instead of 1000…its the same behaviour…right now it is not 5 times slower but rendertime jumps from 6 to 10 minutes.

I don’t know what’s happening…do you think i should try an older builld? I am currently using one of the newer SP1 builds from June (can’t check exact version right now)

thx in advance
Oli

I’m interested in what your rendering??

I don’t think that there are any major changes in this since a long time; but it would be best if we can take a look at the scene to see where the CPU time is spent.

Best regards,
Vlado

a car…:wink:

I only use proxies if the object is duplicated a large number of times - if it’s the only object, it tends to end up slower.

edit: this is assuming theres no memory issues - need to dig about to find a balance.

Ultrasonic! can you tell us how you are implementing the poxy work flow..

After all UVs are layed out properly we convert every single object to a vraymesh and put it on the server and then distribute them to every single worstations/rendernodes local drive. After that we switch the filenames our maya scene to the local Drive as well. This reduces network load dramatically and maya files get way smaller! Also the files open faster and export to vrscenes faster…which means faster preview turnaround times…u see…many many beniefits…

In previous producitons we never felt such dramatic speed hits so it was always a pleasure to work. I have no idea why it is so slow at the moment…

Interesting! we just have an assets folder on the server where we all reference from, using the basic maya referencing work flow. Interesting to nore how other work, thanks!

We haven’t’ used proxies yet in the new service pack, so I can’t be of help, but it’s interesting to hear the workflow. So if I understand properly, a single car is broken out into say, 1000 proxies, one for each mesh part of the car. Is that right? Is this done so you can have more control over rigging/animation?

We recently did a spot with a lot of Cad-data cars that had to be proxied. The majority of each car was treated as a single proxy, except the wheels, which were not proxied, just referenced as mb files, since the tires had to deform. We had simple rigs, but good enough for what we needed, and didn’t break out too many proxies. It was enough for our san to handle easily, so we didn’t need to push any data to the locak rendernodes. Just curious to hear more about why each object is a separate proxy. Seems to me that could be worsening the problem.

I think I found why it’s a bit slow.

Too many objects would definitely cause a slowdown; it is in general always better to have as few proxies as possible for the same geometry.

Best regards,
Vlado

Oli we are using this version of VRay and we don´t have any problems with the proxies.
[2010/Jul/14|12:26:29] V-Ray: V-Ray for Maya version 1.50.SP1 from Jun 23 2010, 08:51:31
[2010/Jul/14|12:26:29] V-Ray: V-Ray core version is 1.90.03

Grüße aus Düdo!